@@ -27,6 +27,7 @@ encode(El, TopXMLNS) ->
     Mod = get_mod(El),
     Mod:do_encode(El, TopXMLNS).
 
+
 get_name(El) ->
     Mod = get_mod(El),
     Mod:do_get_name(El).
@@ -224,15 +225,10 @@ pp(Name, Arity) ->
 
 records() -> [].
 
-get_mod(<<"report">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"status">>, <<"jabber:server">>) -> rfc6120;
 get_mod(<<"priority">>,
         <<"jabber:component:accept">>) ->
     rfc6120;
-get_mod(<<"item-not-found">>,
-        <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
-    rfc6120;
 get_mod(<<"failure">>,
         <<"urn:ietf:params:xml:ns:xmpp-tls">>) ->
     rfc6120;
@@ -245,44 +241,20 @@ get_mod(<<"never">>, <<"urn:xmpp:mam:0">>) -> xep0313;
 get_mod(<<"tie-break">>,
         <<"urn:xmpp:jingle:errors:1">>) ->
     xep0166;
-get_mod(<<"item">>,
-        <<"http://jabber.org/protocol/pubsub">>) ->
-    xep0060;
-get_mod(<<"decline">>,
-        <<"http://jabber.org/protocol/muc#user">>) ->
-    xep0045;
-get_mod(<<"x">>,
-        <<"http://jabber.org/protocol/muc#user">>) ->
-    xep0045;
 get_mod(<<"x509-challenge">>, <<"urn:xmpp:x509:0">>) ->
     xep0417;
-get_mod(<<"failure">>,
-        <<"http://jabber.org/protocol/compress">>) ->
-    xep0138;
-get_mod(<<"resource-constraint">>,
-        <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
 get_mod(<<"unsupported-version">>,
         <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
 get_mod(<<"stream:error">>, <<"jabber:client">>) ->
     rfc6120;
-get_mod(<<"VERSION">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"SORT-STRING">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"item-forbidden">>,
-        <<"http://jabber.org/protocol/pubsub#errors">>) ->
-    xep0060;
-get_mod(<<"history">>,
-        <<"http://jabber.org/protocol/muc">>) ->
-    xep0045;
 get_mod(<<"actor">>,
         <<"http://jabber.org/protocol/muc#user">>) ->
     xep0045;
 get_mod(<<"last">>,
         <<"http://jabber.org/protocol/rsm">>) ->
     xep0059;
-get_mod(<<"inactive">>, <<"urn:xmpp:csi:0">>) ->
-    xep0352;
 get_mod(<<"message">>, <<"jabber:iq:privacy">>) ->
     xep0016;
 get_mod(<<"presence">>, <<"jabber:client">>) -> rfc6120;
@@ -302,6 +274,8 @@ get_mod(<<"error">>, <<"jabber:component:accept">>) ->
 get_mod(<<"password">>, <<"jabber:iq:auth">>) ->
     xep0078;
 get_mod(<<"TZ">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"client-leave">>, <<"urn:xmpp:mix:pam:2">>) ->
+    xep0405;
 get_mod(<<"request">>, <<"urn:xmpp:http:upload">>) ->
     xep0363;
 get_mod(<<"timeout">>, <<"urn:xmpp:jingle:1">>) ->
@@ -335,6 +309,8 @@ get_mod(<<"first">>, <<"jabber:iq:register">>) ->
 get_mod(<<"x">>,
         <<"http://jabber.org/protocol/muc">>) ->
     xep0045;
+get_mod(<<"channel">>, <<"urn:xmpp:mix:roster:0">>) ->
+    xep0405;
 get_mod(<<"media">>, <<"urn:xmpp:media-element">>) ->
     xep0221;
 get_mod(<<"out-of-order">>,
@@ -344,6 +320,8 @@ get_mod(<<"KEYWORD">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"result">>, <<"urn:xmpp:mam:tmp">>) ->
     xep0313;
 get_mod(<<"active">>, <<"urn:xmpp:csi:0">>) -> xep0352;
+get_mod(<<"create">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"slot">>, <<"urn:xmpp:http:upload">>) ->
     xep0363;
 get_mod(<<"data">>,
@@ -367,6 +345,8 @@ get_mod(<<"create">>,
 get_mod(<<"offline">>,
         <<"http://jabber.org/protocol/offline">>) ->
     xep0013;
+get_mod(<<"leave">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"actions">>,
         <<"http://jabber.org/protocol/commands">>) ->
     xep0050;
@@ -442,6 +422,8 @@ get_mod(<<"query">>, <<"jabber:iq:version">>) ->
     xep0092;
 get_mod(<<"archived">>, <<"urn:xmpp:mam:tmp">>) ->
     xep0313;
+get_mod(<<"nick">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"next">>,
         <<"http://jabber.org/protocol/commands">>) ->
     xep0050;
@@ -493,6 +475,8 @@ get_mod(<<"password">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"city">>, <<"jabber:iq:register">>) ->
     xep0077;
+get_mod(<<"jid">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"query">>, <<"urn:xmpp:delegation:1">>) ->
     xep0355;
 get_mod(<<"hash">>, <<"urn:xmpp:hashes:2">>) -> xep0300;
@@ -591,6 +575,8 @@ get_mod(<<"active">>,
 get_mod(<<"invite">>,
         <<"http://jabber.org/protocol/muc#user">>) ->
     xep0045;
+get_mod(<<"setnick">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"no-storage">>, <<"urn:xmpp:hints">>) ->
     xep0334;
 get_mod(<<"stream:stream">>, <<"jabber:client">>) ->
@@ -691,6 +677,9 @@ get_mod(<<"no-store">>, <<"urn:xmpp:hints">>) ->
 get_mod(<<"nick">>,
         <<"http://jabber.org/protocol/nick">>) ->
     xep0172;
+get_mod(<<"hats">>,
+        <<"xmpp:prosody.im/protocol/hats:1">>) ->
+    xep0317;
 get_mod(<<"item">>, <<"jabber:iq:roster">>) -> rfc6121;
 get_mod(<<"redirect">>,
         <<"http://jabber.org/protocol/pubsub#owner">>) ->
@@ -763,6 +752,8 @@ get_mod(<<"candidate-used">>,
 get_mod(<<"not-well-formed">>,
         <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
+get_mod(<<"annotate">>, <<"urn:xmpp:mix:roster:0">>) ->
+    xep0405;
 get_mod(<<"content-type">>,
         <<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
@@ -856,6 +847,8 @@ get_mod(<<"retract">>,
 get_mod(<<"destroy">>,
         <<"http://jabber.org/protocol/muc#owner">>) ->
     xep0045;
+get_mod(<<"subscribe">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"compress">>,
         <<"http://jabber.org/protocol/compress">>) ->
     xep0138;
@@ -1144,6 +1137,8 @@ get_mod(<<"unsupported-encoding">>,
 get_mod(<<"stream:error">>,
         <<"jabber:component:accept">>) ->
     rfc6120;
+get_mod(<<"mix">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"subject">>, <<"jabber:component:accept">>) ->
     rfc6120;
 get_mod(<<"text">>,
@@ -1360,6 +1355,8 @@ get_mod(<<"fin">>, <<"urn:xmpp:inbox:1">>) -> xep0430;
 get_mod(<<"nick">>, <<"jabber:iq:search">>) -> xep0055;
 get_mod(<<"port">>, <<"urn:xmpp:sic:1">>) -> xep0279;
 get_mod(<<"desc">>, <<"jabber:x:data">>) -> xep0004;
+get_mod(<<"destroy">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"no-permanent-store">>,
         <<"urn:xmpp:hints">>) ->
     xep0334;
@@ -1416,7 +1413,12 @@ get_mod(<<"redirect">>,
 get_mod(<<"destroy">>,
         <<"http://jabber.org/protocol/muc#user">>) ->
     xep0045;
+get_mod(<<"participant">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
 get_mod(<<"id">>, <<"jabber:x:event">>) -> xep0022;
+get_mod(<<"hat">>,
+        <<"xmpp:prosody.im/protocol/hats:1">>) ->
+    xep0317;
 get_mod(<<"not-acceptable">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1440,6 +1442,8 @@ get_mod(<<"affiliation">>,
     xep0060;
 get_mod(<<"fin">>, <<"urn:xmpp:mam:0">>) -> xep0313;
 get_mod(<<"enabled">>, <<"urn:xmpp:sm:2">>) -> xep0198;
+get_mod(<<"client-join">>, <<"urn:xmpp:mix:pam:2">>) ->
+    xep0405;
 get_mod(<<"TITLE">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"too-many-subscriptions">>,
         <<"http://jabber.org/protocol/pubsub#errors">>) ->
@@ -1582,6 +1586,37 @@ get_mod(<<"flip-page">>, <<"urn:xmpp:mam:2">>) ->
     xep0313;
 get_mod(<<"received">>, <<"urn:xmpp:receipts">>) ->
     xep0184;
+get_mod(<<"report">>, <<"urn:xmpp:reporting:0">>) ->
+    xep0377;
+get_mod(<<"item-not-found">>,
+        <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
+    rfc6120;
+get_mod(<<"item">>,
+        <<"http://jabber.org/protocol/pubsub">>) ->
+    xep0060;
+get_mod(<<"decline">>,
+        <<"http://jabber.org/protocol/muc#user">>) ->
+    xep0045;
+get_mod(<<"x">>,
+        <<"http://jabber.org/protocol/muc#user">>) ->
+    xep0045;
+get_mod(<<"join">>, <<"urn:xmpp:mix:core:1">>) ->
+    xep0369;
+get_mod(<<"failure">>,
+        <<"http://jabber.org/protocol/compress">>) ->
+    xep0138;
+get_mod(<<"resource-constraint">>,
+        <<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"VERSION">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"item-forbidden">>,
+        <<"http://jabber.org/protocol/pubsub#errors">>) ->
+    xep0060;
+get_mod(<<"history">>,
+        <<"http://jabber.org/protocol/muc">>) ->
+    xep0045;
+get_mod(<<"inactive">>, <<"urn:xmpp:csi:0">>) ->
+    xep0352;
 get_mod(Name, XMLNS) ->
     xmpp_codec_external:lookup(Name, XMLNS).
 
@@ -1597,6 +1632,7 @@ get_mod({x509_revoke, _, _}) -> xep0417;
 get_mod({muc_user, _, _, _, _, _, _}) -> xep0045;
 get_mod({jidprep, _}) -> xep0328;
 get_mod({bytestreams, _, _, _, _, _, _}) -> xep0065;
+get_mod({address, _, _, _, _, _, _}) -> xep0033;
 get_mod({sasl_auth, _, _}) -> rfc6120;
 get_mod({vcard_logo, _, _, _}) -> xep0054;
 get_mod({ps_item, _, _, _, _, _}) -> xep0060;
@@ -1605,6 +1641,7 @@ get_mod({jingle_ft_error, _}) -> xep0234;
 get_mod({legacy_auth, _, _, _, _}) -> xep0078;
 get_mod({stream_features, _}) -> rfc6120;
 get_mod({muc_item, _, _, _, _, _, _, _}) -> xep0045;
+get_mod({muc_hats, _}) -> xep0317;
 get_mod({block_list, _}) -> xep0191;
 get_mod({carbons_received, _}) -> xep0280;
 get_mod({carbons_sent, _}) -> xep0280;
@@ -1625,10 +1662,7 @@ get_mod({x509_cert_chain, _, _}) -> xep0417;
 get_mod({vcard_geo, _, _}) -> xep0054;
 get_mod({xevent, _, _, _, _, _}) -> xep0022;
 get_mod({jingle_content, _, _, _, _, _}) -> xep0166;
-get_mod({bookmark_conference, _, _, _, _, _}) ->
-    xep0048;
 get_mod({feature_register}) -> xep0077;
-get_mod({vcard_name, _, _, _, _, _}) -> xep0054;
 get_mod({pubsub,
          _,
          _,
@@ -1649,9 +1683,6 @@ get_mod({pubsub,
     xep0060;
 get_mod({x_conference, _, _, _, _, _}) -> xep0249;
 get_mod({inbox_query, _}) -> xep0430;
-get_mod({inbox_fin, _, _, _, _}) -> xep0430;
-get_mod({csi, _}) -> xep0352;
-get_mod({mix_join, _, _, _, _}) -> xep0369;
 get_mod({mix_destroy, _}) -> xep0369;
 get_mod({disco_info, _, _, _, _}) -> xep0030;
 get_mod({sm_a, _, _}) -> xep0198;
@@ -1673,41 +1704,11 @@ get_mod({jingle, _, _, _, _, _, _, _}) -> xep0166;
 get_mod({x509_csr, _, _}) -> xep0417;
 get_mod({x509_challenge_failed}) -> xep0417;
 get_mod({stats, _, _}) -> xep0039;
-get_mod({vcard_temp,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _,
-         _}) ->
-    xep0054;
 get_mod({muc, _, _}) -> xep0045;
 get_mod({carbons_enable}) -> xep0280;
 get_mod({carbons_private}) -> xep0280;
 get_mod({mix_leave}) -> xep0369;
+get_mod({mix_roster_channel, _}) -> xep0405;
 get_mod({services, _, _}) -> xep0215;
 get_mod({avatar_info, _, _, _, _, _, _}) -> xep0084;
 get_mod({privacy_list, _, _}) -> xep0016;
@@ -1722,6 +1723,7 @@ get_mod({stanza_id, _, _}) -> xep0359;
 get_mod({delegated, _, _}) -> xep0355;
 get_mod({text, _, _}) -> xep0234;
 get_mod({jingle_ft_received, _, _}) -> xep0234;
+get_mod({muc_hat, _, _}) -> xep0317;
 get_mod({bookmark_storage, _, _}) -> xep0048;
 get_mod({sasl_failure, _, _}) -> rfc6120;
 get_mod({xmpp_session, _}) -> rfc3921;
@@ -1774,7 +1776,6 @@ get_mod({muc_subscription, _, _, _}) -> p1_mucsub;
 get_mod({muc_subscribe, _, _, _, _}) -> p1_mucsub;
 get_mod({feature_csi}) -> xep0352;
 get_mod({ibb_open, _, _, _}) -> xep0047;
-get_mod({roster_item, _, _, _, _, _}) -> rfc6121;
 get_mod({vcard_tel,
          _,
          _,
@@ -1799,7 +1800,6 @@ get_mod({search_item, _, _, _, _, _}) -> xep0055;
 get_mod({xcaptcha, _}) -> xep0158;
 get_mod({avatar_data, _}) -> xep0084;
 get_mod({hash, _, _}) -> xep0300;
-get_mod({roster_query, _, _}) -> rfc6121;
 get_mod({vcard_key, _, _}) -> xep0054;
 get_mod({sm_r, _}) -> xep0198;
 get_mod({media_uri, _, _}) -> xep0221;
@@ -1830,12 +1830,45 @@ get_mod({jingle_ft_file, _, _, _, _, _, _, _, _}) ->
 get_mod({bookmark_url, _, _}) -> xep0048;
 get_mod({gone, _}) -> rfc6120;
 get_mod({sasl_response, _}) -> rfc6120;
+get_mod({vcard_temp,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _,
+         _}) ->
+    xep0054;
 get_mod({chatstate, _}) -> xep0085;
 get_mod({muc_unique, _}) -> xep0045;
 get_mod({mix_create, _}) -> xep0369;
 get_mod({receipt_response, _}) -> xep0184;
 get_mod({sic, _, _, _}) -> xep0279;
 get_mod({idle, _}) -> xep0319;
+get_mod({stanza_error, _, _, _, _, _}) -> rfc6120;
 get_mod({sm_resumed, _, _, _}) -> xep0198;
 get_mod({offline_item, _, _}) -> xep0013;
 get_mod({db_verify, _, _, _, _, _, _}) -> xep0220;
@@ -1845,7 +1878,6 @@ get_mod({muc_decline, _, _, _}) -> xep0045;
 get_mod({sm_enable, _, _, _}) -> xep0198;
 get_mod({offline, _, _, _}) -> xep0013;
 get_mod({mix_client_join, _, _}) -> xep0405;
-get_mod({address, _, _, _, _, _}) -> xep0033;
 get_mod({thumbnail, _, _, _, _}) -> xep0264;
 get_mod({delegation, _, _}) -> xep0355;
 get_mod({x509_challenge, _, _, _}) -> xep0417;
@@ -1854,8 +1886,10 @@ get_mod({vcard_email, _, _, _, _, _, _}) -> xep0054;
 get_mod({ps_affiliation, _, _, _, _}) -> xep0060;
 get_mod({upload_retry, _}) -> xep0363;
 get_mod({x509_register}) -> xep0417;
+get_mod({roster_item, _, _, _, _, _, _}) -> rfc6121;
 get_mod({rsm_set, _, _, _, _, _, _, _}) -> xep0059;
 get_mod({avatar_meta, _, _}) -> xep0084;
+get_mod({roster_query, _, _, _}) -> rfc6121;
 get_mod({unblock, _}) -> xep0191;
 get_mod({stat_error, _, _}) -> xep0039;
 get_mod({sasl_abort}) -> rfc6120;
@@ -1868,7 +1902,9 @@ get_mod({upload_request_0, _, _, _, _}) -> xep0363;
 get_mod({privacy_item, _, _, _, _, _, _, _, _}) ->
     xep0016;
 get_mod({starttls_failure}) -> rfc6120;
+get_mod({mix_roster_annotate}) -> xep0405;
 get_mod({bob_data, _, _, _, _}) -> xep0231;
+get_mod({markable}) -> xep0333;
 get_mod({bind, _, _}) -> rfc6120;
 get_mod({rsm_first, _, _}) -> xep0059;
 get_mod({caps, _, _, _, _}) -> xep0115;
@@ -1879,7 +1915,6 @@ get_mod({muc_unsubscribe, _, _}) -> p1_mucsub;
 get_mod({search, _, _, _, _, _, _, _}) -> xep0055;
 get_mod({expire, _, _}) -> xep0023;
 get_mod({privilege, _, _}) -> xep0356;
-get_mod({stanza_error, _, _, _, _, _, _}) -> rfc6120;
 get_mod({avatar_pointer, _, _, _, _, _, _}) -> xep0084;
 get_mod({muc_invite, _, _, _, _}) -> xep0045;
 get_mod({jingle_reason, _, _, _}) -> xep0166;
@@ -1922,4 +1957,10 @@ get_mod({sm_resume, _, _, _}) -> xep0198;
 get_mod({push_enable, _, _, _}) -> xep0357;
 get_mod({jingle_ft_range, _, _, _}) -> xep0234;
 get_mod({db_result, _, _, _, _, _}) -> xep0220;
+get_mod({bookmark_conference, _, _, _, _, _}) ->
+    xep0048;
+get_mod({vcard_name, _, _, _, _, _}) -> xep0054;
+get_mod({inbox_fin, _, _, _, _}) -> xep0430;
+get_mod({csi, _}) -> xep0352;
+get_mod({mix_join, _, _, _, _}) -> xep0369;
 get_mod(Record) -> xmpp_codec_external:lookup(Record).
